# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool
from pieces_client.models.assets import Assets
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema

class ReuseSuggestion(BaseModel):
    """
    This is the ReuseSuggestion. Mainly creating an additional model here because I imagine that we will want to add some additional data to this in the future (potentially with more numerical data that is emitted from the ML Models)  **Note: suggested is required here because we will want to say if we suggested to take this action of reuse or not.  ** Thoughts here. We could potentially return Assets: which would be an iterable of assets in most relavent order for the user to reuse if they want.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    suggested: StrictBool = Field(..., description="This is a boolean, that will say if you should or should not take action.")
    assets: Assets = Field(...)
    __properties = ["schema", "suggested", "assets"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ReuseSuggestion:
        """Create an instance of ReuseSuggestion from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ReuseSuggestion:
        """Create an instance of ReuseSuggestion from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ReuseSuggestion.parse_obj(obj)

        _obj = ReuseSuggestion.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "suggested": obj.get("suggested"),
            "assets": Assets.from_dict(obj.get("assets")) if obj.get("assets") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.external_provider_profile_data import ExternalProviderProfileData
from pieces_client.models.external_provider_type_enum import ExternalProviderTypeEnum
from pieces_client.models.grouped_timestamp import GroupedTimestamp

class ExternalProvider(BaseModel):
    """
    I know that profileData and user_id have differeing casing but they are done because they map to Auth0's projeecties.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    type: ExternalProviderTypeEnum = Field(...)
    user_id: StrictStr = Field(..., description="This is the user_id within the provider.")
    access_token: Optional[StrictStr] = Field(None, description="This is optional here, but will be present for BB, Github, and google.")
    expires_in: Optional[StrictInt] = Field(None, description="Some providers have an expiration on their access token. IE BB, Google, NOT Github.")
    created: GroupedTimestamp = Field(...)
    updated: GroupedTimestamp = Field(...)
    profile_data: Optional[ExternalProviderProfileData] = Field(None, alias="profileData")
    connection: Optional[StrictStr] = Field(None, description="This is an optional field that will be provided onentreprise connections. ie is type == waad then connection might be PiecesApp. However is other cases,you my find your provider and connection is the exact same string. To decifer between the two, you can use the isSocial bool.")
    is_social: Optional[StrictBool] = Field(None, alias="isSocial")
    __properties = ["schema", "type", "user_id", "access_token", "expires_in", "created", "updated", "profileData", "connection", "isSocial"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExternalProvider:
        """Create an instance of ExternalProvider from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created
        if self.created:
            _dict['created'] = self.created.to_dict()
        # override the default output from pydantic by calling `to_dict()` of updated
        if self.updated:
            _dict['updated'] = self.updated.to_dict()
        # override the default output from pydantic by calling `to_dict()` of profile_data
        if self.profile_data:
            _dict['profileData'] = self.profile_data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExternalProvider:
        """Create an instance of ExternalProvider from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExternalProvider.parse_obj(obj)

        _obj = ExternalProvider.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "type": obj.get("type"),
            "user_id": obj.get("user_id"),
            "access_token": obj.get("access_token"),
            "expires_in": obj.get("expires_in"),
            "created": GroupedTimestamp.from_dict(obj.get("created")) if obj.get("created") is not None else None,
            "updated": GroupedTimestamp.from_dict(obj.get("updated")) if obj.get("updated") is not None else None,
            "profile_data": ExternalProviderProfileData.from_dict(obj.get("profileData")) if obj.get("profileData") is not None else None,
            "connection": obj.get("connection"),
            "is_social": obj.get("isSocial")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class Auth0Identity(BaseModel):
    """
    Contains info retrieved from the identity provider with which the user originally authenticates. Users may also link their profile to multiple identity providers; those identities will then also appear in this array. The contents of an individual identity provider object varies by provider, but it will typically include the following. Link: [https://auth0.com/docs/rules/user-object-in-rules]  Currently left out: - profile_data: (Object) User information associated with the connection. When profiles are linked, it is populated with the associated user info for secondary accounts.  # noqa: E501
    """
    connection: Optional[StrictStr] = Field(None, description="Name of the Auth0 connection used to authenticate the user. ")
    is_social: Optional[StrictBool] = Field(None, alias="isSocial", description="Indicates whether the connection is a social one. ")
    provider: Optional[StrictStr] = Field(None, description="mapped from user_id  -> id")
    user_id: Optional[StrictStr] = Field(None, description="User's unique identifier for this connection/provider.")
    access_token: Optional[StrictStr] = None
    expires_in: Optional[StrictInt] = None
    __properties = ["connection", "isSocial", "provider", "user_id", "access_token", "expires_in"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Auth0Identity:
        """Create an instance of Auth0Identity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Auth0Identity:
        """Create an instance of Auth0Identity from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Auth0Identity.parse_obj(obj)

        _obj = Auth0Identity.parse_obj({
            "connection": obj.get("connection"),
            "is_social": obj.get("isSocial"),
            "provider": obj.get("provider"),
            "user_id": obj.get("user_id"),
            "access_token": obj.get("access_token"),
            "expires_in": obj.get("expires_in")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema

class TrackedAssetEventIdentifierDescriptionPairs(BaseModel):
    """
    These are all of the available event types that are permitted in an object pair notation.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    asset_created: Optional[StrictStr] = Field(None, description="The key value pair for an asset being created.")
    asset_viewed: Optional[StrictStr] = Field(None, description="An asset was viewed")
    asset_format_copied: Optional[StrictStr] = Field(None, description="An asset's format was copied")
    asset_format_downloaded: Optional[StrictStr] = Field(None, description="An asset's format was downloaded")
    asset_deleted: Optional[StrictStr] = Field(None, description="An asset was deleted or not")
    asset_description_updated: Optional[StrictStr] = Field(None, description="An asset was redescribed by the user")
    asset_name_updated: Optional[StrictStr] = Field(None, description="An asset was renamed by the user")
    asset_format_generic_classification_updated: Optional[StrictStr] = Field(None, description="A generic classification was changed on a format within an asset")
    asset_format_specific_classification_updated: Optional[StrictStr] = Field(None, description="A specific classification was changed on a format within an asset")
    asset_creation_failed: Optional[StrictStr] = None
    asset_tag_added: Optional[StrictStr] = None
    asset_link_added: Optional[StrictStr] = None
    asset_link_generated: Optional[StrictStr] = Field(None, description="user generated a link for the asset")
    asset_link_deleted: Optional[StrictStr] = None
    asset_tag_deleted: Optional[StrictStr] = None
    asset_updated: Optional[StrictStr] = Field(None, description="This is just a generic string for an asset was updated.")
    asset_format_value_edited: Optional[StrictStr] = Field(None, description="This is a side effect event for a format value getting edited that exists on an asset.")
    asset_format_updated: Optional[StrictStr] = Field(None, description="This is a generic activity event for an asset getting updated because our format was updated for some reason.")
    asset_link_revoked: Optional[StrictStr] = Field(None, description="This means that a shareable link was revoked.")
    asset_person_added: Optional[StrictStr] = Field(None, description="This just means that a person was added via the user.")
    asset_person_deleted: Optional[StrictStr] = Field(None, description="This just means that a person was deleted via the user.")
    asset_sensitive_added: Optional[StrictStr] = Field(None, description="This just means that a sensitive was added via the user.")
    asset_sensitive_deleted: Optional[StrictStr] = Field(None, description="This just means that a sensitive was deleted via the user.")
    suggested_asset_referenced: Optional[StrictStr] = Field(None, description="This means that an asset was view/used while the user was looking at the suggestion view.")
    searched_asset_referenced: Optional[StrictStr] = Field(None, description="This means that an asset was view/used while the user was looking at the searching view.")
    asset_referenced: Optional[StrictStr] = Field(None, description="This means that an asset was view/used while the user was looking at the default view.")
    activity_asset_referenced: Optional[StrictStr] = Field(None, description="This means that a user referenced an asset by first clicking on an asset within an activity event.(ie from the activity view)")
    asset_annotation_added: Optional[StrictStr] = None
    asset_annotation_deleted: Optional[StrictStr] = None
    asset_annotation_updated: Optional[StrictStr] = None
    asset_hint_added: Optional[StrictStr] = None
    asset_hint_deleted: Optional[StrictStr] = None
    asset_hint_updated: Optional[StrictStr] = None
    asset_anchor_added: Optional[StrictStr] = None
    asset_anchor_deleted: Optional[StrictStr] = None
    asset_anchor_updated: Optional[StrictStr] = None
    __properties = ["schema", "asset_created", "asset_viewed", "asset_format_copied", "asset_format_downloaded", "asset_deleted", "asset_description_updated", "asset_name_updated", "asset_format_generic_classification_updated", "asset_format_specific_classification_updated", "asset_creation_failed", "asset_tag_added", "asset_link_added", "asset_link_generated", "asset_link_deleted", "asset_tag_deleted", "asset_updated", "asset_format_value_edited", "asset_format_updated", "asset_link_revoked", "asset_person_added", "asset_person_deleted", "asset_sensitive_added", "asset_sensitive_deleted", "suggested_asset_referenced", "searched_asset_referenced", "asset_referenced", "activity_asset_referenced", "asset_annotation_added", "asset_annotation_deleted", "asset_annotation_updated", "asset_hint_added", "asset_hint_deleted", "asset_hint_updated", "asset_anchor_added", "asset_anchor_deleted", "asset_anchor_updated"]

    @validator('asset_created')
    def asset_created_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_was_created'):
            raise ValueError("must be one of enum values ('an_asset_was_created')")
        return value

    @validator('asset_viewed')
    def asset_viewed_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_was_viewed'):
            raise ValueError("must be one of enum values ('an_asset_was_viewed')")
        return value

    @validator('asset_format_copied')
    def asset_format_copied_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_preview_format_was_copied'):
            raise ValueError("must be one of enum values ('an_asset_preview_format_was_copied')")
        return value

    @validator('asset_format_downloaded')
    def asset_format_downloaded_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_format_was_downloaded'):
            raise ValueError("must be one of enum values ('an_asset_format_was_downloaded')")
        return value

    @validator('asset_deleted')
    def asset_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_was_deleted'):
            raise ValueError("must be one of enum values ('an_asset_was_deleted')")
        return value

    @validator('asset_description_updated')
    def asset_description_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_was_redescribed_by_the_user'):
            raise ValueError("must be one of enum values ('an_asset_was_redescribed_by_the_user')")
        return value

    @validator('asset_name_updated')
    def asset_name_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_was_renamed_by_the_user'):
            raise ValueError("must be one of enum values ('an_asset_was_renamed_by_the_user')")
        return value

    @validator('asset_format_generic_classification_updated')
    def asset_format_generic_classification_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_generic_classification_was_changed_on_a_format_within_an_asset'):
            raise ValueError("must be one of enum values ('a_generic_classification_was_changed_on_a_format_within_an_asset')")
        return value

    @validator('asset_format_specific_classification_updated')
    def asset_format_specific_classification_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_specific_classification_was_changed_on_a_format_within_an_asset'):
            raise ValueError("must be one of enum values ('a_specific_classification_was_changed_on_a_format_within_an_asset')")
        return value

    @validator('asset_creation_failed')
    def asset_creation_failed_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_failed_to_be_created'):
            raise ValueError("must be one of enum values ('an_asset_failed_to_be_created')")
        return value

    @validator('asset_tag_added')
    def asset_tag_added_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_tag_was_added_by_the_user'):
            raise ValueError("must be one of enum values ('a_tag_was_added_by_the_user')")
        return value

    @validator('asset_link_added')
    def asset_link_added_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_link_was_added_by_the_user'):
            raise ValueError("must be one of enum values ('a_link_was_added_by_the_user')")
        return value

    @validator('asset_link_generated')
    def asset_link_generated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_link_was_generated'):
            raise ValueError("must be one of enum values ('an_asset_link_was_generated')")
        return value

    @validator('asset_link_deleted')
    def asset_link_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_link_was_deleted_by_the_user'):
            raise ValueError("must be one of enum values ('a_link_was_deleted_by_the_user')")
        return value

    @validator('asset_tag_deleted')
    def asset_tag_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_tag_was_deleted_by_the_user'):
            raise ValueError("must be one of enum values ('a_tag_was_deleted_by_the_user')")
        return value

    @validator('asset_updated')
    def asset_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_was_updated'):
            raise ValueError("must be one of enum values ('an_asset_was_updated')")
        return value

    @validator('asset_format_value_edited')
    def asset_format_value_edited_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_specific_format_value_was_edited_on_an_asset'):
            raise ValueError("must be one of enum values ('a_specific_format_value_was_edited_on_an_asset')")
        return value

    @validator('asset_format_updated')
    def asset_format_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_specific_format_was_updated_on_an_asset'):
            raise ValueError("must be one of enum values ('a_specific_format_was_updated_on_an_asset')")
        return value

    @validator('asset_link_revoked')
    def asset_link_revoked_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_link_was_revoked'):
            raise ValueError("must be one of enum values ('an_asset_link_was_revoked')")
        return value

    @validator('asset_person_added')
    def asset_person_added_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_person_was_added_by_the_user'):
            raise ValueError("must be one of enum values ('a_person_was_added_by_the_user')")
        return value

    @validator('asset_person_deleted')
    def asset_person_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_person_was_deleted_by_the_user'):
            raise ValueError("must be one of enum values ('a_person_was_deleted_by_the_user')")
        return value

    @validator('asset_sensitive_added')
    def asset_sensitive_added_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_sensitive_was_added_by_the_user'):
            raise ValueError("must be one of enum values ('a_sensitive_was_added_by_the_user')")
        return value

    @validator('asset_sensitive_deleted')
    def asset_sensitive_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_sensitive_was_deleted_by_the_user'):
            raise ValueError("must be one of enum values ('a_sensitive_was_deleted_by_the_user')")
        return value

    @validator('suggested_asset_referenced')
    def suggested_asset_referenced_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_suggested_asset_was_referenced_by_the_user'):
            raise ValueError("must be one of enum values ('a_suggested_asset_was_referenced_by_the_user')")
        return value

    @validator('searched_asset_referenced')
    def searched_asset_referenced_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_searched_asset_was_referenced_by_the_user'):
            raise ValueError("must be one of enum values ('a_searched_asset_was_referenced_by_the_user')")
        return value

    @validator('asset_referenced')
    def asset_referenced_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_asset_was_referenced_by_the_user'):
            raise ValueError("must be one of enum values ('an_asset_was_referenced_by_the_user')")
        return value

    @validator('activity_asset_referenced')
    def activity_asset_referenced_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_activity_asset_was_referenced_by_the_user'):
            raise ValueError("must be one of enum values ('an_activity_asset_was_referenced_by_the_user')")
        return value

    @validator('asset_annotation_added')
    def asset_annotation_added_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_annotation_was_added_by_the_user'):
            raise ValueError("must be one of enum values ('an_annotation_was_added_by_the_user')")
        return value

    @validator('asset_annotation_deleted')
    def asset_annotation_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_annotation_was_deleted_by_the_user'):
            raise ValueError("must be one of enum values ('an_annotation_was_deleted_by_the_user')")
        return value

    @validator('asset_annotation_updated')
    def asset_annotation_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('an_annotation_was_updated_by_the_user'):
            raise ValueError("must be one of enum values ('an_annotation_was_updated_by_the_user')")
        return value

    @validator('asset_hint_added')
    def asset_hint_added_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_hint_was_added_by_the_user'):
            raise ValueError("must be one of enum values ('a_hint_was_added_by_the_user')")
        return value

    @validator('asset_hint_deleted')
    def asset_hint_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_hint_was_deleted_by_the_user'):
            raise ValueError("must be one of enum values ('a_hint_was_deleted_by_the_user')")
        return value

    @validator('asset_hint_updated')
    def asset_hint_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_hint_was_updated_by_the_user'):
            raise ValueError("must be one of enum values ('a_hint_was_updated_by_the_user')")
        return value

    @validator('asset_anchor_added')
    def asset_anchor_added_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_anchor_was_added_by_the_user'):
            raise ValueError("must be one of enum values ('a_anchor_was_added_by_the_user')")
        return value

    @validator('asset_anchor_deleted')
    def asset_anchor_deleted_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_anchor_was_deleted_by_the_user'):
            raise ValueError("must be one of enum values ('a_anchor_was_deleted_by_the_user')")
        return value

    @validator('asset_anchor_updated')
    def asset_anchor_updated_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('a_anchor_was_updated_by_the_user'):
            raise ValueError("must be one of enum values ('a_anchor_was_updated_by_the_user')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TrackedAssetEventIdentifierDescriptionPairs:
        """Create an instance of TrackedAssetEventIdentifierDescriptionPairs from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TrackedAssetEventIdentifierDescriptionPairs:
        """Create an instance of TrackedAssetEventIdentifierDescriptionPairs from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TrackedAssetEventIdentifierDescriptionPairs.parse_obj(obj)

        _obj = TrackedAssetEventIdentifierDescriptionPairs.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "asset_created": obj.get("asset_created"),
            "asset_viewed": obj.get("asset_viewed"),
            "asset_format_copied": obj.get("asset_format_copied"),
            "asset_format_downloaded": obj.get("asset_format_downloaded"),
            "asset_deleted": obj.get("asset_deleted"),
            "asset_description_updated": obj.get("asset_description_updated"),
            "asset_name_updated": obj.get("asset_name_updated"),
            "asset_format_generic_classification_updated": obj.get("asset_format_generic_classification_updated"),
            "asset_format_specific_classification_updated": obj.get("asset_format_specific_classification_updated"),
            "asset_creation_failed": obj.get("asset_creation_failed"),
            "asset_tag_added": obj.get("asset_tag_added"),
            "asset_link_added": obj.get("asset_link_added"),
            "asset_link_generated": obj.get("asset_link_generated"),
            "asset_link_deleted": obj.get("asset_link_deleted"),
            "asset_tag_deleted": obj.get("asset_tag_deleted"),
            "asset_updated": obj.get("asset_updated"),
            "asset_format_value_edited": obj.get("asset_format_value_edited"),
            "asset_format_updated": obj.get("asset_format_updated"),
            "asset_link_revoked": obj.get("asset_link_revoked"),
            "asset_person_added": obj.get("asset_person_added"),
            "asset_person_deleted": obj.get("asset_person_deleted"),
            "asset_sensitive_added": obj.get("asset_sensitive_added"),
            "asset_sensitive_deleted": obj.get("asset_sensitive_deleted"),
            "suggested_asset_referenced": obj.get("suggested_asset_referenced"),
            "searched_asset_referenced": obj.get("searched_asset_referenced"),
            "asset_referenced": obj.get("asset_referenced"),
            "activity_asset_referenced": obj.get("activity_asset_referenced"),
            "asset_annotation_added": obj.get("asset_annotation_added"),
            "asset_annotation_deleted": obj.get("asset_annotation_deleted"),
            "asset_annotation_updated": obj.get("asset_annotation_updated"),
            "asset_hint_added": obj.get("asset_hint_added"),
            "asset_hint_deleted": obj.get("asset_hint_deleted"),
            "asset_hint_updated": obj.get("asset_hint_updated"),
            "asset_anchor_added": obj.get("asset_anchor_added"),
            "asset_anchor_deleted": obj.get("asset_anchor_deleted"),
            "asset_anchor_updated": obj.get("asset_anchor_updated")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, constr, validator
from pieces_client.models.interacted_asset_interactions import InteractedAssetInteractions

class InteractedAsset(BaseModel):
    """
    A model that represents an asset that has been interacted with.   # noqa: E501
    """
    asset: Optional[constr(strict=True, max_length=36, min_length=36)] = Field(None, description="A uuid model. 36 Characters (4 Dashes, 32 Numbers/Letters) ")
    interactions: Optional[InteractedAssetInteractions] = None
    __properties = ["asset", "interactions"]

    @validator('asset')
    def asset_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}", value):
            raise ValueError(r"must validate the regular expression /[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}/")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InteractedAsset:
        """Create an instance of InteractedAsset from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of interactions
        if self.interactions:
            _dict['interactions'] = self.interactions.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InteractedAsset:
        """Create an instance of InteractedAsset from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return InteractedAsset.parse_obj(obj)

        _obj = InteractedAsset.parse_obj({
            "asset": obj.get("asset"),
            "interactions": InteractedAssetInteractions.from_dict(obj.get("interactions")) if obj.get("interactions") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from pydantic import Field, StrictBool, StrictStr

from typing import Optional

from pieces_client.models.person import Person
from pieces_client.models.persons import Persons
from pieces_client.models.seeded_person import SeededPerson

from pieces_client.api_client import ApiClient
from pieces_client.api_response import ApiResponse
from pieces_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PersonsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def person_disassociate_asset(self, person : Annotated[StrictStr, Field(..., description="This is a uuid that represents a person.")], asset : Annotated[StrictStr, Field(..., description="The id (uuid) of the asset that you are trying to access.")], **kwargs) -> None:  # noqa: E501
        """/persons/{person}/assets/delete/{asset} [POST]  # noqa: E501

        This will update both the asset and the person reference, that will remove a person from an asset(only the references).  This will NOT remove the person. This will NOT remove the asset. This will only update the references so that they are disconnected from one another.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.person_disassociate_asset(person, asset, async_req=True)
        >>> result = thread.get()

        :param person: This is a uuid that represents a person. (required)
        :type person: str
        :param asset: The id (uuid) of the asset that you are trying to access. (required)
        :type asset: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the person_disassociate_asset_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.person_disassociate_asset_with_http_info(person, asset, **kwargs)  # noqa: E501

    @validate_arguments
    def person_disassociate_asset_with_http_info(self, person : Annotated[StrictStr, Field(..., description="This is a uuid that represents a person.")], asset : Annotated[StrictStr, Field(..., description="The id (uuid) of the asset that you are trying to access.")], **kwargs) -> ApiResponse:  # noqa: E501
        """/persons/{person}/assets/delete/{asset} [POST]  # noqa: E501

        This will update both the asset and the person reference, that will remove a person from an asset(only the references).  This will NOT remove the person. This will NOT remove the asset. This will only update the references so that they are disconnected from one another.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.person_disassociate_asset_with_http_info(person, asset, async_req=True)
        >>> result = thread.get()

        :param person: This is a uuid that represents a person. (required)
        :type person: str
        :param asset: The id (uuid) of the asset that you are trying to access. (required)
        :type asset: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'person',
            'asset'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method person_disassociate_asset" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['person']:
            _path_params['person'] = _params['person']

        if _params['asset']:
            _path_params['asset'] = _params['asset']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/persons/{person}/assets/delete/{asset}', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def persons_create_new_person(self, transferables : Annotated[Optional[StrictBool], Field(description="This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)")] = None, seeded_person : Optional[SeededPerson] = None, **kwargs) -> Person:  # noqa: E501
        """/persons/create [POST]  # noqa: E501

        This will create a new person.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.persons_create_new_person(transferables, seeded_person, async_req=True)
        >>> result = thread.get()

        :param transferables: This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)
        :type transferables: bool
        :param seeded_person:
        :type seeded_person: SeededPerson
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Person
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the persons_create_new_person_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.persons_create_new_person_with_http_info(transferables, seeded_person, **kwargs)  # noqa: E501

    @validate_arguments
    def persons_create_new_person_with_http_info(self, transferables : Annotated[Optional[StrictBool], Field(description="This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)")] = None, seeded_person : Optional[SeededPerson] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """/persons/create [POST]  # noqa: E501

        This will create a new person.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.persons_create_new_person_with_http_info(transferables, seeded_person, async_req=True)
        >>> result = thread.get()

        :param transferables: This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)
        :type transferables: bool
        :param seeded_person:
        :type seeded_person: SeededPerson
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Person, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'transferables',
            'seeded_person'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method persons_create_new_person" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('transferables') is not None:  # noqa: E501
            _query_params.append(('transferables', _params['transferables']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['seeded_person'] is not None:
            _body_params = _params['seeded_person']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "Person",
            '500': "str",
        }

        return self.api_client.call_api(
            '/persons/create', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def persons_delete_person(self, person : Annotated[StrictStr, Field(..., description="This is a uuid that represents a person.")], **kwargs) -> None:  # noqa: E501
        """/persons/{person}/delete [POST]  # noqa: E501

        This will delete a specific person.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.persons_delete_person(person, async_req=True)
        >>> result = thread.get()

        :param person: This is a uuid that represents a person. (required)
        :type person: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the persons_delete_person_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.persons_delete_person_with_http_info(person, **kwargs)  # noqa: E501

    @validate_arguments
    def persons_delete_person_with_http_info(self, person : Annotated[StrictStr, Field(..., description="This is a uuid that represents a person.")], **kwargs) -> ApiResponse:  # noqa: E501
        """/persons/{person}/delete [POST]  # noqa: E501

        This will delete a specific person.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.persons_delete_person_with_http_info(person, async_req=True)
        >>> result = thread.get()

        :param person: This is a uuid that represents a person. (required)
        :type person: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'person'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method persons_delete_person" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['person']:
            _path_params['person'] = _params['person']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/persons/{person}/delete', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def persons_snapshot(self, transferables : Annotated[Optional[StrictBool], Field(description="This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)")] = None, **kwargs) -> Persons:  # noqa: E501
        """/persons [GET]  # noqa: E501

        This will get a snapshot of all of your people  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.persons_snapshot(transferables, async_req=True)
        >>> result = thread.get()

        :param transferables: This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)
        :type transferables: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Persons
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the persons_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.persons_snapshot_with_http_info(transferables, **kwargs)  # noqa: E501

    @validate_arguments
    def persons_snapshot_with_http_info(self, transferables : Annotated[Optional[StrictBool], Field(description="This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """/persons [GET]  # noqa: E501

        This will get a snapshot of all of your people  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.persons_snapshot_with_http_info(transferables, async_req=True)
        >>> result = thread.get()

        :param transferables: This is a boolean that will decided if we are want to return the transferable data (default) or not(performance enhancement)
        :type transferables: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Persons, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'transferables'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method persons_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('transferables') is not None:  # noqa: E501
            _query_params.append(('transferables', _params['transferables']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "Persons",
            '500': "str",
        }

        return self.api_client.call_api(
            '/persons', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from pieces_client.models.qgpt_agent_routes import QGPTAgentRoutes
from pieces_client.models.qgpt_question_output import QGPTQuestionOutput
from pieces_client.models.qgpt_relevance_output import QGPTRelevanceOutput
from pieces_client.models.qgpt_stream_enum import QGPTStreamEnum

class QGPTStreamOutput(BaseModel):
    """
    This is the out for the /qgpt/stream endpoint.  200: success 401: invalid authentication/api key 429: Rate limit/Quota exceeded 500: server had an error 503: the engine is currently overloaded  # noqa: E501
    """
    request: Optional[StrictStr] = Field(None, description="This is the id used to represent the stream of response. this will always be present. We will use the value passed inby the client, or we will generate one.")
    relevance: Optional[QGPTRelevanceOutput] = None
    question: Optional[QGPTQuestionOutput] = None
    status: Optional[QGPTStreamEnum] = None
    conversation: StrictStr = Field(..., description="This is the ID of a predefined persisted conversation, if this is not present we will create a new conversation for the input/output.(in the case of a question)")
    status_code: Optional[Union[StrictFloat, StrictInt]] = Field(None, alias="statusCode", description="This will be provided")
    error_message: Optional[StrictStr] = Field(None, alias="errorMessage", description="optional error message is the status code is NOT 200")
    agent_routes: Optional[QGPTAgentRoutes] = Field(None, alias="agentRoutes")
    __properties = ["request", "relevance", "question", "status", "conversation", "statusCode", "errorMessage", "agentRoutes"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> QGPTStreamOutput:
        """Create an instance of QGPTStreamOutput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of relevance
        if self.relevance:
            _dict['relevance'] = self.relevance.to_dict()
        # override the default output from pydantic by calling `to_dict()` of question
        if self.question:
            _dict['question'] = self.question.to_dict()
        # override the default output from pydantic by calling `to_dict()` of agent_routes
        if self.agent_routes:
            _dict['agentRoutes'] = self.agent_routes.to_dict()
        # set to None if status_code (nullable) is None
        # and __fields_set__ contains the field
        if self.status_code is None and "status_code" in self.__fields_set__:
            _dict['statusCode'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> QGPTStreamOutput:
        """Create an instance of QGPTStreamOutput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return QGPTStreamOutput.parse_obj(obj)

        _obj = QGPTStreamOutput.parse_obj({
            "request": obj.get("request"),
            "relevance": QGPTRelevanceOutput.from_dict(obj.get("relevance")) if obj.get("relevance") is not None else None,
            "question": QGPTQuestionOutput.from_dict(obj.get("question")) if obj.get("question") is not None else None,
            "status": obj.get("status"),
            "conversation": obj.get("conversation"),
            "status_code": obj.get("statusCode"),
            "error_message": obj.get("errorMessage"),
            "agent_routes": QGPTAgentRoutes.from_dict(obj.get("agentRoutes")) if obj.get("agentRoutes") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.seeded_classification import SeededClassification
from pieces_client.models.seeded_file import SeededFile
from pieces_client.models.seeded_fragment import SeededFragment

class SeededFormat(BaseModel):
    """
    This is seeded data that will be come a format.  We will throw an Error if, 1) file and fragment are both defined, 2) file and fragment are both null.  if this is being used within the /assets/create endpoint or the /{application}/create endpoint, we will not take the classificaiton into account, as it is only used in the syntax highlighting related endpoints.That being said if you do want to override your classification, please look at the metadata within the file or the fragment.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    file: Optional[SeededFile] = None
    fragment: Optional[SeededFragment] = None
    classification: Optional[SeededClassification] = None
    __properties = ["schema", "file", "fragment", "classification"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SeededFormat:
        """Create an instance of SeededFormat from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of file
        if self.file:
            _dict['file'] = self.file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fragment
        if self.fragment:
            _dict['fragment'] = self.fragment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of classification
        if self.classification:
            _dict['classification'] = self.classification.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SeededFormat:
        """Create an instance of SeededFormat from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SeededFormat.parse_obj(obj)

        _obj = SeededFormat.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "file": SeededFile.from_dict(obj.get("file")) if obj.get("file") is not None else None,
            "fragment": SeededFragment.from_dict(obj.get("fragment")) if obj.get("fragment") is not None else None,
            "classification": SeededClassification.from_dict(obj.get("classification")) if obj.get("classification") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictInt, StrictStr, validator
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema

class OAuthToken(BaseModel):
    """
    A model representing a returnable response for a OAuthGroup Token  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    access_token: StrictStr = Field(..., description="The Access Token")
    token_type: StrictStr = Field(...)
    expires_in: StrictInt = Field(...)
    scope: StrictStr = Field(...)
    refresh_token: Optional[StrictStr] = None
    id_token: Optional[StrictStr] = None
    __properties = ["schema", "access_token", "token_type", "expires_in", "scope", "refresh_token", "id_token"]

    @validator('token_type')
    def token_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in ('Bearer'):
            raise ValueError("must be one of enum values ('Bearer')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OAuthToken:
        """Create an instance of OAuthToken from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OAuthToken:
        """Create an instance of OAuthToken from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return OAuthToken.parse_obj(obj)

        _obj = OAuthToken.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "access_token": obj.get("access_token"),
            "token_type": obj.get("token_type"),
            "expires_in": obj.get("expires_in"),
            "scope": obj.get("scope"),
            "refresh_token": obj.get("refresh_token"),
            "id_token": obj.get("id_token")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class ModelFoundationEnum(str, Enum):
    """
    This is used to describe the foundational models used within POS.
    """

    """
    allowed enum values
    """
    GPT_3_DOT_5 = 'GPT_3.5'
    GPT_4 = 'GPT_4'
    T5 = 'T5'
    LLAMA_2_7_B = 'LLAMA_2_7B'
    LLAMA_2_13_B = 'LLAMA_2_13B'
    LLAMA_2_70_B = 'LLAMA_2_70B'
    CODE_LLAMA_2_7_B = 'CODE_LLAMA_2_7B'
    CODE_LLAMA_2_13_B = 'CODE_LLAMA_2_13B'
    CODE_LLAMA_2_70_B = 'CODE_LLAMA_2_70B'
    BARD = 'BARD'
    ALPACA_7_B = 'ALPACA_7B'
    ALPACA_13_B = 'ALPACA_13B'
    ALPACA_33_B = 'ALPACA_33B'
    ALPACA_65_B = 'ALPACA_65B'
    VICUNA_7_B = 'VICUNA_7B'
    VICUNA_13_B = 'VICUNA_13B'
    VICUNA_33_B = 'VICUNA_33B'
    VICUNA_65_B = 'VICUNA_65B'
    GUANACO_7_B = 'GUANACO_7B'
    GUANACO_13_B = 'GUANACO_13B'
    GUANACO_33_B = 'GUANACO_33B'
    GUANACO_65_B = 'GUANACO_65B'
    OPENLLAMA_7_B = 'OPENLLAMA_7B'
    OPENLLAMA_13_B = 'OPENLLAMA_13B'
    GORILLA_7_B = 'GORILLA_7B'
    GORILLA_13_B = 'GORILLA_13B'
    GORILLA_33_B = 'GORILLA_33B'
    GORILLA_65_B = 'GORILLA_65B'
    WIZARDLM_7_B = 'WIZARDLM_7B'
    WIZARDLM_13_B = 'WIZARDLM_13B'
    WIZARDLM_30_B = 'WIZARDLM_30B'
    YULANCHAT_13_B = 'YULANCHAT_13B'
    YULANCHAT_65_B = 'YULANCHAT_65B'
    REDPAJAMA_3_B = 'REDPAJAMA_3B'
    REDPAJAMA_7_B = 'REDPAJAMA_7B'
    REDPAJAMA_13_B = 'REDPAJAMA_13B'
    REDPAJAMA_33_B = 'REDPAJAMA_33B'
    REDPAJAMA_65_B = 'REDPAJAMA_65B'
    DOLLY_70_M = 'DOLLY_70M'
    DOLLY_160_M = 'DOLLY_160M'
    DOLLY_410_M = 'DOLLY_410M'
    DOLLY_1_B = 'DOLLY_1B'
    DOLLY_1_DOT_4_B = 'DOLLY_1.4B'
    DOLLY_2_DOT_8_B = 'DOLLY_2.8B'
    DOLLY_6_DOT_9_B = 'DOLLY_6.9B'
    DOLLY_12_B = 'DOLLY_12B'
    PYTHIA_70_M = 'PYTHIA_70M'
    PYTHIA_160_M = 'PYTHIA_160M'
    PYTHIA_410_M = 'PYTHIA_410M'
    PYTHIA_1_B = 'PYTHIA_1B'
    PYTHIA_1_DOT_4_B = 'PYTHIA_1.4B'
    PYTHIA_2_DOT_8_B = 'PYTHIA_2.8B'
    PYTHIA_6_DOT_9_B = 'PYTHIA_6.9B'
    PYTHIA_12_B = 'PYTHIA_12B'
    MOSS_7_B = 'MOSS_7B'
    MOSS_13_B = 'MOSS_13B'
    RMKV_LM_100_M = 'RMKV_LM_100M'
    RMKV_LM_400_M = 'RMKV_LM_400M'
    RMKV_LM_1_DOT_5_B = 'RMKV_LM_1.5B'
    RMKV_LM_3_B = 'RMKV_LM_3B'
    RMKV_LM_7_B = 'RMKV_LM_7B'
    RMKV_LM_14_B = 'RMKV_LM_14B'
    STARCODER_15_DOT_5_B = 'STARCODER_15.5B'
    WIZARDCODER_15_B = 'WIZARDCODER_15B'
    SANTACODER_1_DOT_1_B = 'SANTACODER_1.1B'
    TEXT_BISON = 'TEXT_BISON'
    TEXTEMBEDDING_GECKO = 'TEXTEMBEDDING_GECKO'
    CHAT_BISON = 'CHAT_BISON'
    CODE_BISON = 'CODE_BISON'
    CODECHAT_BISON = 'CODECHAT_BISON'
    CODE_GECKO = 'CODE_GECKO'
    DISTILROBERTA = 'DISTILROBERTA'
    MISTRAL_7_B = 'MISTRAL_7B'
    GEMINI = 'GEMINI'
    FAST_TEXT = 'FAST_TEXT'
    UNIXCODER = 'UNIXCODER'

    @classmethod
    def from_json(cls, json_str: str) -> ModelFoundationEnum:
        """Create an instance of ModelFoundationEnum from a JSON string"""
        return ModelFoundationEnum(json.loads(json_str))





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema

class TLPCodeSnippetTagifyCode(BaseModel):
    """
      # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    distribution: StrictStr = Field(..., description="stringified array of numbers")
    inferred_distribution: StrictStr = Field(..., description="stringified array of numbers")
    tags: StrictStr = Field(..., description="stringified array of strings")
    inferred_tags: StrictStr = Field(..., description="stringified array of strings")
    model: StrictStr = Field(..., description="this is the model version ")
    label_version: StrictStr = Field(..., description="This is the version of the file that we are using that contains all the possible tags")
    threshold: Union[StrictFloat, StrictInt] = Field(..., description="this is the minimum score from the model that a tag needs to have to be included in the tags array.")
    inferred_threshold: Union[StrictFloat, StrictInt] = Field(..., description="this is the minimum score from the postprocessing that a tag needs to have to be included in the inferred_tags array.")
    context: StrictStr = Field(..., description="this is the origin in which this asset was created, application(string representation)")
    asset: StrictStr = Field(..., description="This is the asset id.")
    __properties = ["schema", "distribution", "inferred_distribution", "tags", "inferred_tags", "model", "label_version", "threshold", "inferred_threshold", "context", "asset"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TLPCodeSnippetTagifyCode:
        """Create an instance of TLPCodeSnippetTagifyCode from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TLPCodeSnippetTagifyCode:
        """Create an instance of TLPCodeSnippetTagifyCode from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TLPCodeSnippetTagifyCode.parse_obj(obj)

        _obj = TLPCodeSnippetTagifyCode.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "distribution": obj.get("distribution"),
            "inferred_distribution": obj.get("inferred_distribution"),
            "tags": obj.get("tags"),
            "inferred_tags": obj.get("inferred_tags"),
            "model": obj.get("model"),
            "label_version": obj.get("label_version"),
            "threshold": obj.get("threshold"),
            "inferred_threshold": obj.get("inferred_threshold"),
            "context": obj.get("context"),
            "asset": obj.get("asset")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from pieces_client.models.application import Application
from pieces_client.models.conversation_type_enum import ConversationTypeEnum
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.flattened_assets import FlattenedAssets
from pieces_client.models.flattened_websites import FlattenedWebsites
from pieces_client.models.referenced_model import ReferencedModel
from pieces_client.models.seeded_anchor import SeededAnchor
from pieces_client.models.seeded_annotation import SeededAnnotation
from pieces_client.models.seeded_conversation_message import SeededConversationMessage

class SeededConversation(BaseModel):
    """
    This is a pre-Conversation object.  This will hold together a conversation. Ie allthe message within a conversation.  All the additional properties on here used on here like(anchors/assets) are used for context that will seed the conversation.  model is a calculated property, and will be the model of the last message sent if applicable.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    name: Optional[StrictStr] = Field(None, description="This is a name that is customized.")
    favorited: Optional[StrictBool] = None
    application: Optional[Application] = None
    annotations: Optional[conlist(SeededAnnotation)] = None
    messages: Optional[conlist(SeededConversationMessage)] = None
    model: Optional[ReferencedModel] = None
    assets: Optional[FlattenedAssets] = None
    websites: Optional[FlattenedWebsites] = None
    anchors: Optional[conlist(SeededAnchor)] = None
    type: ConversationTypeEnum = Field(...)
    __properties = ["schema", "name", "favorited", "application", "annotations", "messages", "model", "assets", "websites", "anchors", "type"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SeededConversation:
        """Create an instance of SeededConversation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of application
        if self.application:
            _dict['application'] = self.application.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in annotations (list)
        _items = []
        if self.annotations:
            for _item in self.annotations:
                if _item:
                    _items.append(_item.to_dict())
            _dict['annotations'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item in self.messages:
                if _item:
                    _items.append(_item.to_dict())
            _dict['messages'] = _items
        # override the default output from pydantic by calling `to_dict()` of model
        if self.model:
            _dict['model'] = self.model.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        # override the default output from pydantic by calling `to_dict()` of websites
        if self.websites:
            _dict['websites'] = self.websites.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in anchors (list)
        _items = []
        if self.anchors:
            for _item in self.anchors:
                if _item:
                    _items.append(_item.to_dict())
            _dict['anchors'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SeededConversation:
        """Create an instance of SeededConversation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SeededConversation.parse_obj(obj)

        _obj = SeededConversation.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "name": obj.get("name"),
            "favorited": obj.get("favorited"),
            "application": Application.from_dict(obj.get("application")) if obj.get("application") is not None else None,
            "annotations": [SeededAnnotation.from_dict(_item) for _item in obj.get("annotations")] if obj.get("annotations") is not None else None,
            "messages": [SeededConversationMessage.from_dict(_item) for _item in obj.get("messages")] if obj.get("messages") is not None else None,
            "model": ReferencedModel.from_dict(obj.get("model")) if obj.get("model") is not None else None,
            "assets": FlattenedAssets.from_dict(obj.get("assets")) if obj.get("assets") is not None else None,
            "websites": FlattenedWebsites.from_dict(obj.get("websites")) if obj.get("websites") is not None else None,
            "anchors": [SeededAnchor.from_dict(_item) for _item in obj.get("anchors")] if obj.get("anchors") is not None else None,
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.file_metadata import FileMetadata
from pieces_client.models.transferable_bytes import TransferableBytes
from pieces_client.models.transferable_string import TransferableString

class SeededFile(BaseModel):
    """
    This is a base model for a File(Seeded).  We will Throw an Error, if the text and the bytes properties are both null && if both the text and bytes properties are both defined. Ensure that you pass either a text or bytes property.  bytes and string are both optionl but, if both are null or both are defined we will throw an error. So You will be required to pass one or the other, NOT both.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    bytes: Optional[TransferableBytes] = None
    string: Optional[TransferableString] = None
    metadata: Optional[FileMetadata] = None
    __properties = ["schema", "bytes", "string", "metadata"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SeededFile:
        """Create an instance of SeededFile from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bytes
        if self.bytes:
            _dict['bytes'] = self.bytes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of string
        if self.string:
            _dict['string'] = self.string.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metadata
        if self.metadata:
            _dict['metadata'] = self.metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SeededFile:
        """Create an instance of SeededFile from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SeededFile.parse_obj(obj)

        _obj = SeededFile.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "bytes": TransferableBytes.from_dict(obj.get("bytes")) if obj.get("bytes") is not None else None,
            "string": TransferableString.from_dict(obj.get("string")) if obj.get("string") is not None else None,
            "metadata": FileMetadata.from_dict(obj.get("metadata")) if obj.get("metadata") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from pieces_client.models.access_enum import AccessEnum
from pieces_client.models.accessors import Accessors
from pieces_client.models.distributions import Distributions
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.flattened_asset import FlattenedAsset
from pieces_client.models.flattened_assets import FlattenedAssets
from pieces_client.models.grouped_timestamp import GroupedTimestamp
from pieces_client.models.score import Score

class Share(BaseModel):
    """
    This represents what information that is relavent to anything and every sharing related. v1 will look very bare and will add more and more data as we go!  if user is undefined && access is public then we have an asset that is publicly available.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    id: StrictStr = Field(..., description="This is the uuid that represents this share model.")
    user: Optional[StrictStr] = Field(None, description="this is the uuid of the user that the share is created for.")
    asset: Optional[FlattenedAsset] = None
    assets: Optional[FlattenedAssets] = None
    link: StrictStr = Field(..., description="This is the prebuilt link.")
    access: AccessEnum = Field(...)
    accessors: Accessors = Field(...)
    created: GroupedTimestamp = Field(...)
    short: StrictStr = Field(..., description="This is a shortened version of our uuid.")
    name: Optional[StrictStr] = Field(None, description="this is an optional name we can give to the link, ie ?p=JAVASCRIPT or what ever the user wants as long as it is available.")
    distributions: Optional[Distributions] = None
    score: Optional[Score] = None
    __properties = ["schema", "id", "user", "asset", "assets", "link", "access", "accessors", "created", "short", "name", "distributions", "score"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Share:
        """Create an instance of Share from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of asset
        if self.asset:
            _dict['asset'] = self.asset.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        # override the default output from pydantic by calling `to_dict()` of accessors
        if self.accessors:
            _dict['accessors'] = self.accessors.to_dict()
        # override the default output from pydantic by calling `to_dict()` of created
        if self.created:
            _dict['created'] = self.created.to_dict()
        # override the default output from pydantic by calling `to_dict()` of distributions
        if self.distributions:
            _dict['distributions'] = self.distributions.to_dict()
        # override the default output from pydantic by calling `to_dict()` of score
        if self.score:
            _dict['score'] = self.score.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Share:
        """Create an instance of Share from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Share.parse_obj(obj)

        _obj = Share.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "id": obj.get("id"),
            "user": obj.get("user"),
            "asset": FlattenedAsset.from_dict(obj.get("asset")) if obj.get("asset") is not None else None,
            "assets": FlattenedAssets.from_dict(obj.get("assets")) if obj.get("assets") is not None else None,
            "link": obj.get("link"),
            "access": obj.get("access"),
            "accessors": Accessors.from_dict(obj.get("accessors")) if obj.get("accessors") is not None else None,
            "created": GroupedTimestamp.from_dict(obj.get("created")) if obj.get("created") is not None else None,
            "short": obj.get("short"),
            "name": obj.get("name"),
            "distributions": Distributions.from_dict(obj.get("distributions")) if obj.get("distributions") is not None else None,
            "score": Score.from_dict(obj.get("score")) if obj.get("score") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TLPDirectedDiscoveryFilterEnum(str, Enum):
    """
    Code block type like function, class, abstract
    """

    """
    allowed enum values
    """
    FUNCTION = 'FUNCTION'
    METHOD = 'METHOD'
    CLASS = 'CLASS'
    STRUCT = 'STRUCT'
    ABSTRACT = 'ABSTRACT'
    COMMENT = 'COMMENT'
    IMPORT = 'IMPORT'
    IF = 'IF'
    LOOP = 'LOOP'
    RETURN = 'RETURN'

    @classmethod
    def from_json(cls, json_str: str) -> TLPDirectedDiscoveryFilterEnum:
        """Create an instance of TLPDirectedDiscoveryFilterEnum from a JSON string"""
        return TLPDirectedDiscoveryFilterEnum(json.loads(json_str))





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from pieces_client.models.application import Application
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.health import Health
from pieces_client.models.user_profile import UserProfile

class Context(BaseModel):
    """
    A Context that is returned from almost all calls to the ContextAPI  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    os: StrictStr = Field(..., description="This is th UUID of the OS that this context is currently connected to. This attempts to be the same as Segment's anonmyousId feild. It is attempted to be set at initial installation at Pieces/.identity/.os")
    application: Application = Field(...)
    health: Health = Field(...)
    user: Optional[UserProfile] = None
    __properties = ["schema", "os", "application", "health", "user"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Context:
        """Create an instance of Context from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of application
        if self.application:
            _dict['application'] = self.application.to_dict()
        # override the default output from pydantic by calling `to_dict()` of health
        if self.health:
            _dict['health'] = self.health.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Context:
        """Create an instance of Context from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Context.parse_obj(obj)

        _obj = Context.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "os": obj.get("os"),
            "application": Application.from_dict(obj.get("application")) if obj.get("application") is not None else None,
            "health": Health.from_dict(obj.get("health")) if obj.get("health") is not None else None,
            "user": UserProfile.from_dict(obj.get("user")) if obj.get("user") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.externally_sourced_enum import ExternallySourcedEnum
from pieces_client.models.mailgun_metadata import MailgunMetadata

class PersonBasicType(BaseModel):
    """
    This is all optional properties around the most basic information around a non-pieces user.  A Basic type will NOT have a scope as it is not an actual pieces user.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    username: Optional[StrictStr] = Field(None, description="username or twitter handle...etc")
    name: Optional[StrictStr] = Field(None, description="This is the name of the basic user.")
    picture: Optional[StrictStr] = Field(None, description="this is a url picture representation of a user.")
    email: Optional[StrictStr] = Field(None, description="an email that was extracted.")
    sourced: Optional[ExternallySourcedEnum] = None
    url: Optional[StrictStr] = Field(None, description="This is a specific url that this basic user came from.")
    mailgun: Optional[MailgunMetadata] = None
    __properties = ["schema", "username", "name", "picture", "email", "sourced", "url", "mailgun"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PersonBasicType:
        """Create an instance of PersonBasicType from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mailgun
        if self.mailgun:
            _dict['mailgun'] = self.mailgun.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PersonBasicType:
        """Create an instance of PersonBasicType from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PersonBasicType.parse_obj(obj)

        _obj = PersonBasicType.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "username": obj.get("username"),
            "name": obj.get("name"),
            "picture": obj.get("picture"),
            "email": obj.get("email"),
            "sourced": obj.get("sourced"),
            "url": obj.get("url"),
            "mailgun": MailgunMetadata.from_dict(obj.get("mailgun")) if obj.get("mailgun") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from pieces_client.models.allocation_cloud_status import AllocationCloudStatus
from pieces_client.models.allocation_cloud_urls import AllocationCloudUrls
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.grouped_timestamp import GroupedTimestamp

class AllocationCloud(BaseModel):
    """
    update && version: will be present only if your cloud was successfully spun up && running.  updated: is the last time this was updated.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    id: StrictStr = Field(..., description="This is a uuid that represents this cloud.(this is the same as the userid)")
    user: StrictStr = Field(..., description="this is your useruuid.")
    urls: AllocationCloudUrls = Field(...)
    status: AllocationCloudStatus = Field(...)
    project: StrictStr = Field(..., description="This is the project that this is attached to.")
    updated: Optional[GroupedTimestamp] = None
    version: Optional[StrictStr] = Field(None, description="this is the current version of the server.")
    region: Optional[StrictStr] = Field(None, description="this is the region where the project is defined.")
    __properties = ["schema", "id", "user", "urls", "status", "project", "updated", "version", "region"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AllocationCloud:
        """Create an instance of AllocationCloud from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of urls
        if self.urls:
            _dict['urls'] = self.urls.to_dict()
        # override the default output from pydantic by calling `to_dict()` of status
        if self.status:
            _dict['status'] = self.status.to_dict()
        # override the default output from pydantic by calling `to_dict()` of updated
        if self.updated:
            _dict['updated'] = self.updated.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AllocationCloud:
        """Create an instance of AllocationCloud from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return AllocationCloud.parse_obj(obj)

        _obj = AllocationCloud.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "id": obj.get("id"),
            "user": obj.get("user"),
            "urls": AllocationCloudUrls.from_dict(obj.get("urls")) if obj.get("urls") is not None else None,
            "status": AllocationCloudStatus.from_dict(obj.get("status")) if obj.get("status") is not None else None,
            "project": obj.get("project"),
            "updated": GroupedTimestamp.from_dict(obj.get("updated")) if obj.get("updated") is not None else None,
            "version": obj.get("version"),
            "region": obj.get("region")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt
from pieces_client.models.assets import Assets
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.reuse_suggestion import ReuseSuggestion
from pieces_client.models.save_suggestion import SaveSuggestion
from pieces_client.models.suggestion_target import SuggestionTarget

class Suggestion(BaseModel):
    """
    This is the model return by the connector's suggest endpoint.  Note: assets are the assets that this target was ran against.  distribution is the distribution that we generated from comparing the target to the asset's vectors.(currently uuid(assetid) : value that is the difference between the asset and the target) **could potentially make an additional model here that is an array from most to least relevent.  *** distribution is required but we are currently unable to reflect that with our current dart generation.  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    reuse: ReuseSuggestion = Field(...)
    save: SaveSuggestion = Field(...)
    target: SuggestionTarget = Field(...)
    assets: Assets = Field(...)
    distribution: Optional[Dict[str, Union[StrictFloat, StrictInt]]] = None
    __properties = ["schema", "reuse", "save", "target", "assets", "distribution"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Suggestion:
        """Create an instance of Suggestion from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of reuse
        if self.reuse:
            _dict['reuse'] = self.reuse.to_dict()
        # override the default output from pydantic by calling `to_dict()` of save
        if self.save:
            _dict['save'] = self.save.to_dict()
        # override the default output from pydantic by calling `to_dict()` of target
        if self.target:
            _dict['target'] = self.target.to_dict()
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Suggestion:
        """Create an instance of Suggestion from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Suggestion.parse_obj(obj)

        _obj = Suggestion.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "reuse": ReuseSuggestion.from_dict(obj.get("reuse")) if obj.get("reuse") is not None else None,
            "save": SaveSuggestion.from_dict(obj.get("save")) if obj.get("save") is not None else None,
            "target": SuggestionTarget.from_dict(obj.get("target")) if obj.get("target") is not None else None,
            "assets": Assets.from_dict(obj.get("assets")) if obj.get("assets") is not None else None,
            "distribution": obj.get("distribution")
        })
        return _obj





# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt
from pieces_client.models.space import Space

class TrackedAssetsEventSearchMetadataResults(BaseModel):
    """
    Numbers related to search results  # noqa: E501
    """
    fuzzy: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="Total number of fuzzy results")
    exact: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="Total number of exact results")
    assets: Optional[FlattenedAssets] = None
    space: Optional[Space] = None
    __properties = ["fuzzy", "exact", "assets", "space"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TrackedAssetsEventSearchMetadataResults:
        """Create an instance of TrackedAssetsEventSearchMetadataResults from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of assets
        if self.assets:
            _dict['assets'] = self.assets.to_dict()
        # override the default output from pydantic by calling `to_dict()` of space
        if self.space:
            _dict['space'] = self.space.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TrackedAssetsEventSearchMetadataResults:
        """Create an instance of TrackedAssetsEventSearchMetadataResults from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TrackedAssetsEventSearchMetadataResults.parse_obj(obj)

        _obj = TrackedAssetsEventSearchMetadataResults.parse_obj({
            "fuzzy": obj.get("fuzzy"),
            "exact": obj.get("exact"),
            "assets": FlattenedAssets.from_dict(obj.get("assets")) if obj.get("assets") is not None else None,
            "space": Space.from_dict(obj.get("space")) if obj.get("space") is not None else None
        })
        return _obj

from pieces_client.models.flattened_assets import FlattenedAssets
TrackedAssetsEventSearchMetadataResults.update_forward_refs()




# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from pydantic import Field, StrictStr, conlist, validator

from typing import Optional

from pieces_client.models.auth0_user import Auth0User
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema
from pieces_client.models.o_auth_token import OAuthToken
from pieces_client.models.resulted_pkce import ResultedPKCE

from pieces_client.api_client import ApiClient
from pieces_client.api_response import ApiResponse
from pieces_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class Auth0Api:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def auth0_logout(self, client_id : Annotated[Optional[StrictStr], Field(description="The client ID of the Auth0 Instance")] = None, return_to : Annotated[Optional[StrictStr], Field(description="The URL that the logout endpoint will return to")] = None, **kwargs) -> str:  # noqa: E501
        """https://auth.pieces.services/v2/logout [GET]  # noqa: E501

        https://auth0.com/docs/api/authentication#logout  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.auth0_logout(client_id, return_to, async_req=True)
        >>> result = thread.get()

        :param client_id: The client ID of the Auth0 Instance
        :type client_id: str
        :param return_to: The URL that the logout endpoint will return to
        :type return_to: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: str
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the auth0_logout_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.auth0_logout_with_http_info(client_id, return_to, **kwargs)  # noqa: E501

    @validate_arguments
    def auth0_logout_with_http_info(self, client_id : Annotated[Optional[StrictStr], Field(description="The client ID of the Auth0 Instance")] = None, return_to : Annotated[Optional[StrictStr], Field(description="The URL that the logout endpoint will return to")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """https://auth.pieces.services/v2/logout [GET]  # noqa: E501

        https://auth0.com/docs/api/authentication#logout  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.auth0_logout_with_http_info(client_id, return_to, async_req=True)
        >>> result = thread.get()

        :param client_id: The client ID of the Auth0 Instance
        :type client_id: str
        :param return_to: The URL that the logout endpoint will return to
        :type return_to: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(str, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'client_id',
            'return_to'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method auth0_logout" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('client_id') is not None:  # noqa: E501
            _query_params.append(('client_id', _params['client_id']))

        if _params.get('return_to') is not None:  # noqa: E501
            _query_params.append(('returnTo', _params['return_to']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['text/html'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "str",
        }

        return self.api_client.call_api(
            '/v2/logout', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def authorize_auth0(self, audience : Annotated[StrictStr, Field(..., description=" The unique identifier of the target API you want to access.")], scope : Annotated[conlist(StrictStr), Field(..., description="The scopes which you want to request authorization for. These must be separated by a space. You can request any of the standard OpenID Connect (OIDC) scopes about users, such as profile and email, custom claims that must conform to a namespaced format, or any scopes supported by the target API (for example, read:contacts). Include offline_access to get a Refresh Token.")], response_type : Annotated[StrictStr, Field(..., description="Indicates to Auth0 which OAuth 2.0 Flow you want to perform. Use code for Authorization Code Grant (PKCE) Flow.")], client_id : Annotated[StrictStr, Field(..., description="Your application's Client ID.")], code_challenge_method : Annotated[StrictStr, Field(..., description="Method used to generate the challenge. The PKCE spec defines two methods, S256 and plain, however, Auth0 supports only S256 since the latter is discouraged.")], code_challenge : Annotated[StrictStr, Field(..., description="Generated challenge from the code_verifier.")], response_mode : StrictStr, state : Annotated[Optional[StrictStr], Field(description="An opaque value the clients adds to the initial request that Auth0 includes when redirecting the back to the client. This value must be used by the client to prevent CSRF attacks.")] = None, redirect_uri : Annotated[Optional[StrictStr], Field(description="The URL to which Auth0 will redirect the browser after authorization has been granted by the user.")] = None, connection : Annotated[Optional[StrictStr], Field(description="The name of the connection configured to your application.")] = None, prompt : Annotated[Optional[StrictStr], Field(description="To initiate a silent authentication request, use prompt=none (see Remarks for more info).")] = None, **kwargs) -> ResultedPKCE:  # noqa: E501
        """https://auth.pieces.services/authorize [GET]  # noqa: E501

        An endpoint that is used locally authenticate via a PKCE Flow.  Example https://auth.pieces.services /authorize?audience=https%3A%2F%2Fpieces.us.auth0.com%2Fapi%2Fv2%2F&scope=email+profile+offline_access+openid&response_type=code&client_id=9sW4Pa1LEjX67l6VO14u0207NLYeXnu1&redirect_uri=http%3A%2F%2Flocalhost%3A3000%2Fpkce%2Fresponse%2Fcode&code_challenge_method=S256&code_challenge=yxRssZxdfBpMigRmDxAety1QU72Bd5WnDUbtlsCZOnk&response_mode=form_post&state=4bd0b9a389b4b229602346c33913b4c3c199628a90011ab3a901302ab62b3832  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.authorize_auth0(audience, scope, response_type, client_id, code_challenge_method, code_challenge, response_mode, state, redirect_uri, connection, prompt, async_req=True)
        >>> result = thread.get()

        :param audience:  The unique identifier of the target API you want to access. (required)
        :type audience: str
        :param scope: The scopes which you want to request authorization for. These must be separated by a space. You can request any of the standard OpenID Connect (OIDC) scopes about users, such as profile and email, custom claims that must conform to a namespaced format, or any scopes supported by the target API (for example, read:contacts). Include offline_access to get a Refresh Token. (required)
        :type scope: List[str]
        :param response_type: Indicates to Auth0 which OAuth 2.0 Flow you want to perform. Use code for Authorization Code Grant (PKCE) Flow. (required)
        :type response_type: str
        :param client_id: Your application's Client ID. (required)
        :type client_id: str
        :param code_challenge_method: Method used to generate the challenge. The PKCE spec defines two methods, S256 and plain, however, Auth0 supports only S256 since the latter is discouraged. (required)
        :type code_challenge_method: str
        :param code_challenge: Generated challenge from the code_verifier. (required)
        :type code_challenge: str
        :param response_mode: (required)
        :type response_mode: str
        :param state: An opaque value the clients adds to the initial request that Auth0 includes when redirecting the back to the client. This value must be used by the client to prevent CSRF attacks.
        :type state: str
        :param redirect_uri: The URL to which Auth0 will redirect the browser after authorization has been granted by the user.
        :type redirect_uri: str
        :param connection: The name of the connection configured to your application.
        :type connection: str
        :param prompt: To initiate a silent authentication request, use prompt=none (see Remarks for more info).
        :type prompt: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ResultedPKCE
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the authorize_auth0_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.authorize_auth0_with_http_info(audience, scope, response_type, client_id, code_challenge_method, code_challenge, response_mode, state, redirect_uri, connection, prompt, **kwargs)  # noqa: E501

    @validate_arguments
    def authorize_auth0_with_http_info(self, audience : Annotated[StrictStr, Field(..., description=" The unique identifier of the target API you want to access.")], scope : Annotated[conlist(StrictStr), Field(..., description="The scopes which you want to request authorization for. These must be separated by a space. You can request any of the standard OpenID Connect (OIDC) scopes about users, such as profile and email, custom claims that must conform to a namespaced format, or any scopes supported by the target API (for example, read:contacts). Include offline_access to get a Refresh Token.")], response_type : Annotated[StrictStr, Field(..., description="Indicates to Auth0 which OAuth 2.0 Flow you want to perform. Use code for Authorization Code Grant (PKCE) Flow.")], client_id : Annotated[StrictStr, Field(..., description="Your application's Client ID.")], code_challenge_method : Annotated[StrictStr, Field(..., description="Method used to generate the challenge. The PKCE spec defines two methods, S256 and plain, however, Auth0 supports only S256 since the latter is discouraged.")], code_challenge : Annotated[StrictStr, Field(..., description="Generated challenge from the code_verifier.")], response_mode : StrictStr, state : Annotated[Optional[StrictStr], Field(description="An opaque value the clients adds to the initial request that Auth0 includes when redirecting the back to the client. This value must be used by the client to prevent CSRF attacks.")] = None, redirect_uri : Annotated[Optional[StrictStr], Field(description="The URL to which Auth0 will redirect the browser after authorization has been granted by the user.")] = None, connection : Annotated[Optional[StrictStr], Field(description="The name of the connection configured to your application.")] = None, prompt : Annotated[Optional[StrictStr], Field(description="To initiate a silent authentication request, use prompt=none (see Remarks for more info).")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """https://auth.pieces.services/authorize [GET]  # noqa: E501

        An endpoint that is used locally authenticate via a PKCE Flow.  Example https://auth.pieces.services /authorize?audience=https%3A%2F%2Fpieces.us.auth0.com%2Fapi%2Fv2%2F&scope=email+profile+offline_access+openid&response_type=code&client_id=9sW4Pa1LEjX67l6VO14u0207NLYeXnu1&redirect_uri=http%3A%2F%2Flocalhost%3A3000%2Fpkce%2Fresponse%2Fcode&code_challenge_method=S256&code_challenge=yxRssZxdfBpMigRmDxAety1QU72Bd5WnDUbtlsCZOnk&response_mode=form_post&state=4bd0b9a389b4b229602346c33913b4c3c199628a90011ab3a901302ab62b3832  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.authorize_auth0_with_http_info(audience, scope, response_type, client_id, code_challenge_method, code_challenge, response_mode, state, redirect_uri, connection, prompt, async_req=True)
        >>> result = thread.get()

        :param audience:  The unique identifier of the target API you want to access. (required)
        :type audience: str
        :param scope: The scopes which you want to request authorization for. These must be separated by a space. You can request any of the standard OpenID Connect (OIDC) scopes about users, such as profile and email, custom claims that must conform to a namespaced format, or any scopes supported by the target API (for example, read:contacts). Include offline_access to get a Refresh Token. (required)
        :type scope: List[str]
        :param response_type: Indicates to Auth0 which OAuth 2.0 Flow you want to perform. Use code for Authorization Code Grant (PKCE) Flow. (required)
        :type response_type: str
        :param client_id: Your application's Client ID. (required)
        :type client_id: str
        :param code_challenge_method: Method used to generate the challenge. The PKCE spec defines two methods, S256 and plain, however, Auth0 supports only S256 since the latter is discouraged. (required)
        :type code_challenge_method: str
        :param code_challenge: Generated challenge from the code_verifier. (required)
        :type code_challenge: str
        :param response_mode: (required)
        :type response_mode: str
        :param state: An opaque value the clients adds to the initial request that Auth0 includes when redirecting the back to the client. This value must be used by the client to prevent CSRF attacks.
        :type state: str
        :param redirect_uri: The URL to which Auth0 will redirect the browser after authorization has been granted by the user.
        :type redirect_uri: str
        :param connection: The name of the connection configured to your application.
        :type connection: str
        :param prompt: To initiate a silent authentication request, use prompt=none (see Remarks for more info).
        :type prompt: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ResultedPKCE, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'audience',
            'scope',
            'response_type',
            'client_id',
            'code_challenge_method',
            'code_challenge',
            'response_mode',
            'state',
            'redirect_uri',
            'connection',
            'prompt'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method authorize_auth0" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('audience') is not None:  # noqa: E501
            _query_params.append(('audience', _params['audience']))

        if _params.get('scope') is not None:  # noqa: E501
            _query_params.append(('scope', _params['scope']))
            _collection_formats['scope'] = 'ssv'

        if _params.get('response_type') is not None:  # noqa: E501
            _query_params.append(('response_type', _params['response_type']))

        if _params.get('client_id') is not None:  # noqa: E501
            _query_params.append(('client_id', _params['client_id']))

        if _params.get('state') is not None:  # noqa: E501
            _query_params.append(('state', _params['state']))

        if _params.get('redirect_uri') is not None:  # noqa: E501
            _query_params.append(('redirect_uri', _params['redirect_uri']))

        if _params.get('code_challenge_method') is not None:  # noqa: E501
            _query_params.append(('code_challenge_method', _params['code_challenge_method']))

        if _params.get('code_challenge') is not None:  # noqa: E501
            _query_params.append(('code_challenge', _params['code_challenge']))

        if _params.get('connection') is not None:  # noqa: E501
            _query_params.append(('connection', _params['connection']))

        if _params.get('prompt') is not None:  # noqa: E501
            _query_params.append(('prompt', _params['prompt']))

        if _params.get('response_mode') is not None:  # noqa: E501
            _query_params.append(('response_mode', _params['response_mode']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/x-www-form-urlencoded'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "ResultedPKCE",
        }

        return self.api_client.call_api(
            '/authorize', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def exchange_for_auth0_token(self, grant_type : Annotated[StrictStr, Field(..., description="Denotes the flow you are using. For Authorization Code, use authorization_code or refresh_token.")], client_id : Annotated[StrictStr, Field(..., description="Your application's Client ID.")], code : Annotated[StrictStr, Field(..., description="The Authorization Code received from the initial /authorize call.")], redirect_uri : Annotated[StrictStr, Field(..., description="This is required only if it was set at the GET /authorize endpoint. The values must match.")], code_verifier : Annotated[StrictStr, Field(..., description="Cryptographically random key that was used to generate the code_challenge passed to /authorize.")], var_schema : Optional[EmbeddedModelSchema] = None, audience : Annotated[Optional[StrictStr], Field(description="The audience domain: i.e. https://pieces.us.auth0.com")] = None, **kwargs) -> OAuthToken:  # noqa: E501
        """https://auth.pieces.services/oauth/token [POST]  # noqa: E501

        An endpoint to generate a OAuth Token for an authentication flow.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.exchange_for_auth0_token(grant_type, client_id, code, redirect_uri, code_verifier, var_schema, audience, async_req=True)
        >>> result = thread.get()

        :param grant_type: Denotes the flow you are using. For Authorization Code, use authorization_code or refresh_token. (required)
        :type grant_type: str
        :param client_id: Your application's Client ID. (required)
        :type client_id: str
        :param code: The Authorization Code received from the initial /authorize call. (required)
        :type code: str
        :param redirect_uri: This is required only if it was set at the GET /authorize endpoint. The values must match. (required)
        :type redirect_uri: str
        :param code_verifier: Cryptographically random key that was used to generate the code_challenge passed to /authorize. (required)
        :type code_verifier: str
        :param var_schema:
        :type var_schema: EmbeddedModelSchema
        :param audience: The audience domain: i.e. https://pieces.us.auth0.com
        :type audience: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: OAuthToken
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the exchange_for_auth0_token_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.exchange_for_auth0_token_with_http_info(grant_type, client_id, code, redirect_uri, code_verifier, var_schema, audience, **kwargs)  # noqa: E501

    @validate_arguments
    def exchange_for_auth0_token_with_http_info(self, grant_type : Annotated[StrictStr, Field(..., description="Denotes the flow you are using. For Authorization Code, use authorization_code or refresh_token.")], client_id : Annotated[StrictStr, Field(..., description="Your application's Client ID.")], code : Annotated[StrictStr, Field(..., description="The Authorization Code received from the initial /authorize call.")], redirect_uri : Annotated[StrictStr, Field(..., description="This is required only if it was set at the GET /authorize endpoint. The values must match.")], code_verifier : Annotated[StrictStr, Field(..., description="Cryptographically random key that was used to generate the code_challenge passed to /authorize.")], var_schema : Optional[EmbeddedModelSchema] = None, audience : Annotated[Optional[StrictStr], Field(description="The audience domain: i.e. https://pieces.us.auth0.com")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """https://auth.pieces.services/oauth/token [POST]  # noqa: E501

        An endpoint to generate a OAuth Token for an authentication flow.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.exchange_for_auth0_token_with_http_info(grant_type, client_id, code, redirect_uri, code_verifier, var_schema, audience, async_req=True)
        >>> result = thread.get()

        :param grant_type: Denotes the flow you are using. For Authorization Code, use authorization_code or refresh_token. (required)
        :type grant_type: str
        :param client_id: Your application's Client ID. (required)
        :type client_id: str
        :param code: The Authorization Code received from the initial /authorize call. (required)
        :type code: str
        :param redirect_uri: This is required only if it was set at the GET /authorize endpoint. The values must match. (required)
        :type redirect_uri: str
        :param code_verifier: Cryptographically random key that was used to generate the code_challenge passed to /authorize. (required)
        :type code_verifier: str
        :param var_schema:
        :type var_schema: EmbeddedModelSchema
        :param audience: The audience domain: i.e. https://pieces.us.auth0.com
        :type audience: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(OAuthToken, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'grant_type',
            'client_id',
            'code',
            'redirect_uri',
            'code_verifier',
            'var_schema',
            'audience'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method exchange_for_auth0_token" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['var_schema']:
            _form_params.append(('schema', _params['var_schema']))

        if _params['grant_type']:
            _form_params.append(('grant_type', _params['grant_type']))

        if _params['client_id']:
            _form_params.append(('client_id', _params['client_id']))

        if _params['code']:
            _form_params.append(('code', _params['code']))

        if _params['redirect_uri']:
            _form_params.append(('redirect_uri', _params['redirect_uri']))

        if _params['code_verifier']:
            _form_params.append(('code_verifier', _params['code_verifier']))

        if _params['audience']:
            _form_params.append(('audience', _params['audience']))

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/x-www-form-urlencoded']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "OAuthToken",
        }

        return self.api_client.call_api(
            '/oauth/token', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_auth0_user_info(self, **kwargs) -> Auth0User:  # noqa: E501
        """https://auth.pieces.services/userinfo [GET]  # noqa: E501

        Get the users info from the Auth0 API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_auth0_user_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Auth0User
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_auth0_user_info_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_auth0_user_info_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def get_auth0_user_info_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """https://auth.pieces.services/userinfo [GET]  # noqa: E501

        Get the users info from the Auth0 API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_auth0_user_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Auth0User, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_auth0_user_info" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['auth0', 'auth0', 'auth0']  # noqa: E501

        _response_types_map = {
            '200': "Auth0User",
        }

        return self.api_client.call_api(
            '/userinfo', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    Pieces Isomorphic OpenAPI

    Endpoints for Assets, Formats, Users, Asset, Format, User.

    The version of the OpenAPI document: 1.0
    Contact: tsavo@pieces.app
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr
from pieces_client.models.auth0_open_ai_user_metadata import Auth0OpenAIUserMetadata
from pieces_client.models.auth0_user_allocation_metadata import Auth0UserAllocationMetadata
from pieces_client.models.embedded_model_schema import EmbeddedModelSchema

class Auth0UserMetadata(BaseModel):
    """
    User Metadata from Auth0  # noqa: E501
    """
    var_schema: Optional[EmbeddedModelSchema] = Field(None, alias="schema")
    global_id: StrictStr = Field(...)
    cloud_key: Optional[StrictStr] = None
    stripe_customer_id: Optional[StrictStr] = Field(None, description="A customer ID that is added to the user in the case of payments")
    vanityname: Optional[StrictStr] = Field(None, description="this is the vanityname of the user.(set from their custom CNAME dns record.) ie mark.pieces.cloud where \"mark\" is the vanityname.")
    allocation: Optional[Auth0UserAllocationMetadata] = None
    open_ai: Optional[Auth0OpenAIUserMetadata] = Field(None, alias="open_AI")
    __properties = ["schema", "global_id", "cloud_key", "stripe_customer_id", "vanityname", "allocation", "open_AI"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Auth0UserMetadata:
        """Create an instance of Auth0UserMetadata from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of var_schema
        if self.var_schema:
            _dict['schema'] = self.var_schema.to_dict()
        # override the default output from pydantic by calling `to_dict()` of allocation
        if self.allocation:
            _dict['allocation'] = self.allocation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of open_ai
        if self.open_ai:
            _dict['open_AI'] = self.open_ai.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Auth0UserMetadata:
        """Create an instance of Auth0UserMetadata from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Auth0UserMetadata.parse_obj(obj)

        _obj = Auth0UserMetadata.parse_obj({
            "var_schema": EmbeddedModelSchema.from_dict(obj.get("schema")) if obj.get("schema") is not None else None,
            "global_id": obj.get("global_id"),
            "cloud_key": obj.get("cloud_key"),
            "stripe_customer_id": obj.get("stripe_customer_id"),
            "vanityname": obj.get("vanityname"),
            "allocation": Auth0UserAllocationMetadata.from_dict(obj.get("allocation")) if obj.get("allocation") is not None else None,
            "open_ai": Auth0OpenAIUserMetadata.from_dict(obj.get("open_AI")) if obj.get("open_AI") is not None else None
        })
        return _obj


